@@ -1,113 +1,73 @@
 from gettext import gettext as _
 import sys
 import argparse
-from gi.repository import Gtk, Gdk, Gio, GLib, Handy
+from gi.repository import Gtk, Gio, GLib
 from .confManager import ConfManager
 from .app_window import HydraPaperAppWindow
-from .settings_box import HydraPaperSettingsWindow
+from .preferences_window import PreferencesWindow
 from .is_image import is_image
 from .monitor_parser import build_monitors_autodetect
 from .apply_wallpapers import apply_wallpapers
+from .base_app import BaseApp, AppAction
 
 
-class HydraPaperApplication(Gtk.Application):
+class HydraPaperApplication(BaseApp):
     def __init__(self, **kwargs):
-        super().__init__(
-            application_id='org.gabmus.hydrapaper',
-            flags=Gio.ApplicationFlags.HANDLES_COMMAND_LINE,
-            **kwargs
-        )
         self.confman = ConfManager()
-        self.window = HydraPaperAppWindow()
-        self.window.connect('destroy', self.on_destroy_window)
-
-    def do_startup(self):
-        Gtk.Application.do_startup(self)
-        Handy.init()
-        stateful_actions = [
-            {
-                'name': 'spanned_mode',
-                'func': self.toggle_spanned_mode,
-                'type': 'bool',
-                # 'accel': '<Control>h',
-                'confman_key': 'spanned_mode'
-            }
-        ]
-        actions = [
-            {
-                'name': 'set_random_wallpaper',
-                'func': lambda *args: self.apply_random(),
-                'accel': '<Primary><Shift>r'
-            },
-            {
-                'name': 'settings',
-                'func': self.show_settings_window,
-                'accel': '<Primary>comma'
-            },
-            {
-                'name': 'shortcuts',
-                'func': self.show_shortcuts_window,
-                'accel': '<Primary>question'
-            },
-            {
-                'name': 'about',
-                'func': self.show_about_dialog
-            },
-            {
-                'name': 'quit',
-                'func': self.on_destroy_window,
-                'accel': '<Primary>q'
-            }
-        ]
-
-        for sa in stateful_actions:
-            c_action = None
-            if sa['type'] == 'bool':
-                c_action = Gio.SimpleAction.new_stateful(
-                    sa['name'],
-                    None,
-                    GLib.Variant.new_boolean(
-                        self.confman.conf[sa['confman_key']]
-                    )
+        super().__init__(
+            app_id='org.gabmus.hydrapaper',
+            app_name='HydraPaper',
+            app_actions=[
+                AppAction(
+                    name='spanned_mode',
+                    func=self.toggle_spanned_mode,
+                    accel=None,
+                    stateful=True,
+                    state_type=AppAction.StateType.BOOL,
+                    state_default=self.confman.conf['spanned_mode']
+                ),
+                AppAction(
+                    name='set_random_wallpaper',
+                    func=lambda *args: self.apply_random(),
+                    accel='<Primary><Shift>r'
+                ),
+                AppAction(
+                    name='settings',
+                    func=self.show_preferences_window,
+                    accel='<Primary>comma'
+                ),
+                AppAction(
+                    name='shortcuts',
+                    func=self.show_shortcuts_window,
+                    accel='<Primary>question'
+                ),
+                AppAction(
+                    name='about',
+                    func=self.show_about_dialog
+                ),
+                AppAction(
+                    name='quit',
+                    func=self.on_destroy_window,
+                    accel='<Primary>q'
+                ),
+                AppAction(
+                    name='search',
+                    func=self.toggle_search,
+                    accel='<Primary>f'
                 )
-            elif sa['type'] == 'radio':
-                c_action = Gio.SimpleAction.new_stateful(
-                    sa['name'],
-                    GLib.VariantType.new('s'),
-                    GLib.Variant('s', self.confman.conf[sa['confman_key']])
-                )
-            else:
-                raise ValueError(
-                    f'Stateful Action: unsupported type `{sa["type"]}`'
-                )
-            c_action.connect('activate', sa['func'])
-            self.add_action(c_action)
-            if 'accel' in sa.keys():
-                self.set_accels_for_action(
-                    f'app.{sa["name"]}',
-                    [sa['accel']]
-                )
+            ],
+            flags=Gio.ApplicationFlags.HANDLES_COMMAND_LINE,
+            css_resource='/org/gabmus/hydrapaper/ui/gtk_style.css'
+        )
 
-        for a in actions:
-            c_action = Gio.SimpleAction.new(a['name'], None)
-            c_action.connect('activate', a['func'])
-            self.add_action(c_action)
-            if 'accel' in a.keys():
-                self.set_accels_for_action(
-                    f'app.{a["name"]}',
-                    [a['accel']]
-                )
-
-    def toggle_spanned_mode(self, action: Gio.SimpleAction, *args):
-        action.change_state(
-            GLib.Variant.new_boolean(not action.get_state().get_boolean())
+    def toggle_search(self, *args):
+        self.window.headerbar.search_toggle.set_active(
+            not self.window.headerbar.search_toggle.get_active()
         )
-        self.confman.conf['spanned_mode'] = action.get_state().get_boolean()
-        self.confman.emit('hydrapaper_spanned_mode_changed', '')
 
     def show_about_dialog(self, *args):
         about_builder = Gtk.Builder.new_from_resource(
-            '/org/gabmus/hydrapaper/aboutdialog.glade'
+            '/org/gabmus/hydrapaper/aboutdialog.ui'
         )
         dialog = about_builder.get_object('aboutdialog')
         dialog.set_modal(True)
@@ -120,23 +80,20 @@ class HydraPaperApplication(Gtk.Application):
 
     def show_shortcuts_window(self, *args):
         shortcuts_win = Gtk.Builder.new_from_resource(
-            '/org/gabmus/hydrapaper/ui/shortcutsWindow.xml'
+            '/org/gabmus/hydrapaper/ui/shortcutsWindow.ui'
         ).get_object('shortcuts-hydrapaper')
         shortcuts_win.props.section_name = 'shortcuts'
         shortcuts_win.set_transient_for(self.window)
         # shortcuts_win.set_attached_to(self.window)
         shortcuts_win.set_modal(True)
         shortcuts_win.present()
-        shortcuts_win.show_all()
+        shortcuts_win.show()
 
-    def show_settings_window(self, *args):
-        settings_win = HydraPaperSettingsWindow()
-        settings_win.set_transient_for(self.window)
-        # settings_win.set_attached_to(self.window)
-        settings_win.set_modal(True)
-        settings_win.present()
+    def show_preferences_window(self, *args):
+        preferences_win = PreferencesWindow(self.window)
+        preferences_win.present()
 
-    def apply_random(self, lockscreen=False):
+    def apply_random(self, set_dark=False):
         from random import randint
         monitors = build_monitors_autodetect()
         all_wallpapers = self.confman.wallpapers
@@ -145,9 +102,9 @@ class HydraPaperApplication(Gtk.Application):
                 randint(0, len(all_wallpapers)-1)
             ] for i in range(len(monitors))
         ]
-        self.apply_from_cli(wallpapers, lockscreen=lockscreen)
+        self.apply_from_cli(wallpapers, set_dark=set_dark)
 
-    def apply_from_cli(self, wlist_cli, modes=None, lockscreen=False):
+    def apply_from_cli(self, wlist_cli, modes=None, set_dark=False):
         # check all the passed wallpapers to be correct
         monitors = build_monitors_autodetect()
         if len(wlist_cli) < len(monitors):
@@ -189,22 +146,14 @@ class HydraPaperApplication(Gtk.Application):
             n_monitors[m.name] = m.wallpaper
         self.confman.conf['monitors'] = n_monitors
         self.confman.save_conf()
-        apply_wallpapers(monitors, lockscreen=lockscreen)
+        apply_wallpapers(monitors, set_dark=set_dark)
 
     def do_activate(self):
+        super().do_activate()
+        self.window = HydraPaperAppWindow()
+        self.window.connect('close-request', self.on_destroy_window)
         self.add_window(self.window)
-        stylecontext = Gtk.StyleContext()
-        provider = Gtk.CssProvider()
-        provider.load_from_data('''
-            .wallpapers-flowbox {
-                padding-top: 24px;
-            }
-        '''.encode())
-        stylecontext.add_provider_for_screen(
-            Gdk.Screen.get_default(),
-            provider,
-            Gtk.STYLE_PROVIDER_PRIORITY_APPLICATION
-        )
+        set_dark = not not self.args.set_dark
         if self.args:
             if self.args.wallpaper_path:
                 self.apply_from_cli(
@@ -212,16 +161,23 @@ class HydraPaperApplication(Gtk.Application):
                     self.args.wallpaper_modes[0]
                     if self.args.wallpaper_modes
                     else None,
-                    self.args.set_lockscreen
+                    set_dark=set_dark
                 )
                 self.quit()
                 exit(0)
             if self.args.set_random:
-                self.apply_random(self.args.set_lockscreen)
+                self.apply_random(set_dark=set_dark)
                 self.quit()
                 exit(0)
         self.window.present()
-        self.window.show_all()
+        self.window.show()
+
+    def toggle_spanned_mode(self, action: Gio.SimpleAction, *args):
+        action.change_state(
+            GLib.Variant.new_boolean(not action.get_state().get_boolean())
+        )
+        self.confman.conf['spanned_mode'] = action.get_state().get_boolean()
+        self.confman.emit('hydrapaper_spanned_mode_changed', '')
 
     def do_command_line(self, args):
         """
@@ -246,18 +202,18 @@ class HydraPaperApplication(Gtk.Application):
             help=_('specify the modes for the wallpapers (zoom, center_black, '
                    'center_blur, fit_black, fit_blur)')
         )
+        parser.add_argument(
+            '-d', '--darkmode',
+            dest='set_dark',
+            action='store_true',
+            help=_('set the dark mode wallpapers (specific to GNOME 42+)')
+        )
         parser.add_argument(
             '-r', '--random',
             dest='set_random',
             action='store_true',
             help=_('set wallpapers randomly')
         )
-        parser.add_argument(
-            '-l', '--lockscreen',
-            dest='set_lockscreen',
-            action='store_true',
-            help=_('set lockscreen wallpapers instead of desktop ones')
-        )
         # parse the command line stored in args,
         # but skip the first element (the filename)
         self.args = parser.parse_args(args.get_arguments()[1:])
