@@ -6,6 +6,7 @@ from .is_image import is_image
 from os import makedirs, listdir, system
 from os import environ as Env
 import json
+from threading import Thread
 
 pictures_dir = GLib.get_user_special_dir(GLib.UserDirectory.DIRECTORY_PICTURES)
 if not pictures_dir:
@@ -19,8 +20,8 @@ if not pictures_dir:
 
 class ConfManagerSignaler(GObject.Object):
     __gsignals__ = {
-        'hydrapaper_flowbox_selection_mode_changed': (
-            GObject.SIGNAL_RUN_FIRST,
+        'dark_mode_changed': (
+            GObject.SignalFlags.RUN_FIRST,
             None,
             (str,)
         ),
@@ -66,7 +67,7 @@ class ConfManager(metaclass=Singleton):
                 'active': True
             }
         ],
-        'selection_mode': 'single',
+        'dark_mode': False,
         'monitors': {},
         'favorites': [],
         'folders_popover_full_path': False,
@@ -76,6 +77,16 @@ class ConfManager(metaclass=Singleton):
         'windowsize': {
             'width': 600,
             'height': 400
+        },
+        'enable_daemon': True,
+        'last_wps': {
+            'spanned': False,
+            'wps': {}
+        },  # saved when applying wallpapers, retrieved by daemon
+        'Daemon': {
+            'wallpaper_rotation_enabled': False,
+            'wallpaper_rotation_sleep_time': 30,
+            'rotating_wallpapers': []  # list of lists of rotating wallpapers
         }
     }
 
@@ -97,29 +108,17 @@ class ConfManager(metaclass=Singleton):
         )
 
         if self.is_flatpak:
-            self.path = Path(
-                f'{Env.get("XDG_CONFIG_HOME")}/org.gabmus.hydrapaper.json'
-            )
-            self.cache_path = f'{Env.get("XDG_CACHE_HOME")}/hydrapaper'
-            self.gnome_version_path = \
-                '/run/host/usr/share/gnome/gnome-version.xml'
+            self.config_home = Env.get('XDG_CONFIG_HOME')
+            self.cache_home = Env.get('XDG_CACHE_HOME')
         else:
-            self.path = Path(f'{Env.get("HOME")}/.config/hydrapaper.json')
-            self.cache_path = f'{Env.get("HOME")}/.cache/hydrapaper'
-            self.gnome_version_path = '/usr/share/gnome/gnome-version.xml'
+            self.config_home = f'{Env.get("HOME")}/.config'
+            self.cache_home = f'{Env.get("HOME")}/.cache'
+        self.path = Path(
+            f'{self.config_home}/org.gabmus.hydrapaper.json'
+        )
+        self.cache_path = f'{self.cache_home}/org.gabmus.hydrapaper'
         self.thumbs_cache_path = f'{self.cache_path}/thumbnails/'
-        if isfile(self.gnome_version_path):
-            with open(self.gnome_version_path, 'r') as fd:
-                for line in fd.readlines():
-                    if '<minor>' in line:
-                        self.has_lockscreen_wallpaper = (
-                            '36' not in line or '38' not in line
-                        )
-                        break
-        else:
-            self.has_lockscreen_wallpaper = True
 
-        self.conf = None
         if isfile(str(self.path)):
             try:
                 with open(self.path) as fd:
@@ -168,6 +167,9 @@ class ConfManager(metaclass=Singleton):
             fd.write(json.dumps(self.conf))
             fd.close()
 
+    def save_conf_async(self):
+        Thread(target=self.save_conf).start()
+
     def populate_wallpapers(self):
         self.wallpapers = []
         for index, folder in enumerate(self.conf['wallpapers_paths']):
