@@ -1,15 +1,17 @@
-from gi.repository import Gio
 from PIL import Image
 from PIL.ImageOps import fit
 from PIL.ImageFilter import GaussianBlur
 from os import environ as Env
 from subprocess import run
 import re
+from .confManager import ConfManager
+# from .set_wallpaper_portal import set_wallpaper
 
-TMP_DIR = '/tmp/HydraPaper/'
 SWAY_CONF_PATH = f'{Env.get("HOME")}/.config/sway/config'
 SWAYLOCK_CONF_PATH = f'{Env.get("HOME")}/.swaylock/config'
 
+confman = ConfManager()
+
 
 def cut_image(image_path, resolution, save_path):
     with Image.open(image_path) as image:
@@ -24,10 +26,10 @@ def cut_image(image_path, resolution, save_path):
 def get_combined_resolution(monitors):
     return (
         max([
-            m.offset_x + m.width * m.scaling for m in monitors
+            (m.offset_x + m.width) * m.scaling for m in monitors
         ]),
         max([
-            m.offset_y + m.height * m.scaling for m in monitors
+            (m.offset_y + m.height) * m.scaling for m in monitors
         ])
     )
 
@@ -42,7 +44,11 @@ def get_center_offset(img, bg):
 def resize_letterbox(img, sw, sh):
     nw = 0
     nh = 0
-    portrait = (img.width == img.height and sw > sh) or img.width < img.height
+    # old, weird and error prone
+    # portrait = (
+    #     img.width == img.height and sw > sh) or img.width < img.height
+    # )
+    portrait = img.width / img.height < sw / sh
     if portrait:
         nh = sh
         nw = int((sh * img.width) / img.height)
@@ -66,7 +72,7 @@ def multi_setup_pillow(monitors, save_path, wp_setter_func=None):
         if 'fit' in monitor.mode or 'center' in monitor.mode:
             if 'black' in monitor.mode:
                 bg = Image.new('RGB', (monitor.width, monitor.height))
-            elif 'blur' in monitor.mode:
+            else:  # if 'blur' in monitor.mode:
                 bg = blur_img(n_img, monitor.width, monitor.height)
             if 'fit' in monitor.mode or (
                 n_img.height > monitor.height or
@@ -82,7 +88,9 @@ def multi_setup_pillow(monitors, save_path, wp_setter_func=None):
     resolutions = [
         (m.width * m.scaling, m.height * m.scaling) for m in monitors
     ]
-    offsets = [(m.offset_x, m.offset_y) for m in monitors]
+    offsets = [
+        (m.offset_x * m.scaling, m.offset_y * m.scaling) for m in monitors
+    ]
 
     final_image_width, final_image_height = get_combined_resolution(monitors)
 
@@ -98,16 +106,40 @@ def multi_setup_pillow(monitors, save_path, wp_setter_func=None):
 
 
 def __set_wallpaper_gsettings(gsettings_path, wp_key, mode_key, path, wp_mode):
-    gsettings = Gio.Settings.new(gsettings_path)
-    gsettings.set_string(wp_key, path)
-    gsettings.set_string(mode_key, wp_mode)
+    # set_wallpaper(path)
+    # return
+    cmd = 'gsettings set'
+    if confman.is_flatpak:
+        cmd = 'flatpak-spawn --host ' + cmd
+    for t in [(wp_key, path), (mode_key, wp_mode)]:
+        run(
+            '{0} {1} {2} "{3}"'.format(
+                cmd, gsettings_path, t[0], t[1]
+            ),
+            shell=True
+        )
+    # return
+    # gsettings = Gio.Settings.new(gsettings_path)
+    # gsettings.set_string(wp_key, path)
+    # gsettings.set_string(mode_key, wp_mode)
 
 
-def set_wallpaper_gnome(path, wp_mode='spanned', lockscreen=False):
+def set_wallpaper_gnome(path, wp_mode='spanned', set_dark=False):
     __set_wallpaper_gsettings(
         gsettings_path=(
-            'org.gnome.desktop.screensaver' if lockscreen
-            else 'org.gnome.desktop.background'
+            'org.gnome.desktop.background'
+        ),
+        wp_key='picture-uri-dark' if set_dark else 'picture-uri',
+        mode_key='picture-options',
+        path='file://{}'.format(path),
+        wp_mode=wp_mode
+    )
+
+
+def set_wallpaper_cinnamon(path, wp_mode='spanned'):
+    __set_wallpaper_gsettings(
+        gsettings_path=(
+            'org.cinnamon.desktop.background'
         ),
         wp_key='picture-uri',
         mode_key='picture-options',
@@ -116,26 +148,7 @@ def set_wallpaper_gnome(path, wp_mode='spanned', lockscreen=False):
     )
 
 
-def set_wallpaper_cinnamon(path, wp_mode='spanned', lockscreen=False):
-    if lockscreen:
-        print('Lock screen wallpaper on Cinnamon unsupported')
-        return
-    __set_wallpaper_gsettings(
-        gsettings_path=(
-            'org.cinnamon.desktop.screensaver' if lockscreen
-            else'org.cinnamon.desktop.background'
-        ),
-        wp_key='picture-uri',
-        mode_key='picture-options',
-        path='file://{}'.format(path),
-        wp_mode=wp_mode
-    )
-
-
-def set_wallpaper_mate(path, wp_mode='spanned', lockscreen=False):
-    if lockscreen:
-        print('Lock screen wallpaper on MATE unsupported')
-        return
+def set_wallpaper_mate(path, wp_mode='spanned'):
     __set_wallpaper_gsettings(
         gsettings_path='org.mate.background',
         wp_key='picture-filename',
@@ -145,22 +158,15 @@ def set_wallpaper_mate(path, wp_mode='spanned', lockscreen=False):
     )
 
 
-def set_wallpaper_sway(monitors, lockscreen=False):
-    conf_path = SWAYLOCK_CONF_PATH if lockscreen else SWAY_CONF_PATH
+def set_wallpaper_sway(monitors):
+    conf_path = SWAY_CONF_PATH
     with open(conf_path) as fd:
         conf = fd.read()
         fd.close()
-    if lockscreen:
-        n_conf = re.sub(r'image=.*', '', conf).strip()
-        n_conf += '\n' + '\n'.join([
-            f'image={m.name}:{m.wallpaper.replace(":", "::")}'
-            for m in monitors
-        ])
-    else:
-        n_conf = re.sub(r'output .* bg .*', '', conf).strip()
-        n_conf += '\n' + '\n'.join([
-            f'output {m.name} bg {m.wallpaper} fill' for m in monitors
-        ])
+    n_conf = re.sub(r'output .* bg .*', '', conf).strip()
+    n_conf += '\n' + '\n'.join([
+        f'output {m.name} bg {m.wallpaper} fill' for m in monitors
+    ])
     with open(conf_path, 'w') as fd:
         fd.write(n_conf)
         fd.close()
